﻿using System.Text;

using gfoidl.Base64;

namespace anbs_cp.Classes.Encrypt;

/// <summary>
/// Класс для шифровки строк
/// </summary>
public static class StringEncrypt
{
    /// <summary>
    /// Метод для шифрования строки <paramref name="text"/>
    /// </summary>
    /// <param name="text">Строка, которая должна быть зашифрована</param>
    /// <returns>Этот статический метод возвращает зашифрованную строку <paramref name="text"/></returns>
    public static string Encrypt (string text)
    {
        byte[] byteText = Encoding.UTF8.GetBytes(text);
        return Base64.Url.Encode(byteText);
    }

    /// <summary>
    /// Метод для шифрования массива строк <paramref name="bytes"/>
    /// </summary>
    /// <param name="bytes">Массив строк</param>
    /// <returns>Этот статический метод возвращает зашифрованную строку из массива <paramref name="bytes"/></returns>
    public static string EncryptBytes (byte[] bytes) => Base64.Url.Encode(bytes);

    /// <summary>
    /// Метод для дешифрования строки <paramref name="text"/>
    /// </summary>
    /// <param name="text">Строка, которая должна быть дешифрована</param>
    /// <returns>Этот статический метод возвращает дешифрованную строку <paramref name="text"/></returns>
    public static string Decrypt (string text)
    {
        string guidBase64Url = text.Replace('+', '-').Replace('/', '_').TrimEnd('=');
        return Encoding.UTF8.GetString(Base64.Url.Decode(guidBase64Url));
    }

    /// <summary>
    /// Метод для дешифрования в массив byte
    /// </summary>
    /// <param name="text">Строка, которая должна быть дешифрована</param>
    /// <returns>Этот статический метод возвращает дешифрованный массива byte[]</returns>
    public static byte[] DecryptBytes (string text)
    {
        string guidBase64Url = text.Replace('+', '-').Replace('/', '_').TrimEnd('=');
        return Base64.Url.Decode(guidBase64Url);
    }
}